@@ -7,14 +7,14 @@ chain.default <- function(x, ...) {
   chain(as_index(x), ...)
 }
 
-chain.ind <- function(x, link = rep(1, length(levels(x))), ...) {
-  if (x$chain) {
+chain.ind <- function(x, link = rep(1, nlevels(x)), ...) {
+  if (x$chainable) {
     link <- as.numeric(link)
     if (length(link) != length(x$levels)) {
       stop(gettext("'link' must have a value for each level of 'x'"))
     }
-    x$chain <- FALSE
-    x$index[[1]] <- x$index[[1]] * link
+    x$chainable <- FALSE
+    x$index[[1L]] <- x$index[[1L]] * link
     x$index[] <- Reduce(`*`, x$index, accumulate = TRUE)
     # contributions are difficult to chain, so remove them
     x$has_contrib <- FALSE
@@ -30,12 +30,12 @@ unchain <- function(x, ...) {
 }
 
 unchain.default <- function(x, ...) {
-  unchain(as_index(x, chain = FALSE), ...)
+  unchain(as_index(x, chainable = FALSE), ...)
 }
 
 unchain.ind <- function(x, ...) {
-  if (!x$chain) {
-    x$chain <- TRUE
+  if (!x$chainable) {
+    x$chainable <- TRUE
     x$index[-1L] <- Map(`/`, x$index[-1L], x$index[-length(x$index)])
     # contributions are difficult to unchain, so remove them
     x$has_contrib <- FALSE
@@ -51,11 +51,11 @@ rebase <- function(x, ...) {
 }
 
 rebase.default <- function(x, ...) {
-  rebase(as_index(x, chain = FALSE), ...)
+  rebase(as_index(x, chainable = FALSE), ...)
 }
 
-rebase.ind <- function(x, base = rep(1, length(levels(x))), ...) {
-  if (!x$chain) {
+rebase.ind <- function(x, base = rep(1, nlevels(x)), ...) {
+  if (!x$chainable) {
     base <- as.numeric(base)
     if (length(base) != length(x$levels)) {
       stop(gettext("'base' must have a value for each level of 'x'"))
@@ -70,6 +70,11 @@ rebase.ind <- function(x, base = rep(1, length(levels(x))), ...) {
 }
 
 #---- Test ----
+is_chainable_index <- function(x) {
+  is_index(x) && x$chainable
+}
+
 is_chain_index <- function(x) {
-  is_index(x) && x$chain
-}
\ No newline at end of file
+  warning(gettext("'is_chain_index()' is deprecated; use 'is_chainable_index()' instead"))
+  is_chainable_index(x)
+}
